Changelog
=========

0.2.0
-----
**release date:** 2013-10-31

* Add str method
* More explicit exceptions
* Change repr format to use ascii only


0.1.5
-----
**release date:** 2013-10-21

* Add a fromcode method on Language class
* Add a codes attribute on converters


0.1.4
-----
**release date:** 2013-10-20

* Fix converters not raising NoConversionError


0.1.3
-----
**release date:** 2013-09-29

* Fix source distribution


0.1.2
-----
**release date:** 2013-09-29

* Add missing files to source distribution


0.1.1
-----
**release date:** 2013-09-28

* Fix python3 support


0.1
---
**release date:** 2013-09-28

* Initial version
